// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ==  http://www.amdis-fem.org                                              ==
// ==                                                                        ==
// ============================================================================
//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.



/** \file CompositeFEMMethods.h */

#ifndef AMDIS_COMPOSITEFEMMETHODS_H
#define AMDIS_COMPOSITEFEMMETHODS_H

#include "AbstractFunction.h"
#include "DOFVector.h"
#include "FiniteElemSpace.h"
#include "ElementLevelSet.h"

using namespace AMDiS;

class CompositeFEMMethods
{
public:
  /// Set all dof-values on domain with positive level set function values to val.
  static void setPosLsToVal(
	      DOFVector<double> *dof,
	      const double &val,
	      const DOFVector<double> *lsFct_dof);

  /**
   * Set all dof-values on domain with positive level set function values
   * to values of function fct.
   */
  static void setPosLsToFct(
	      DOFVector<double> *dof,
	      const AbstractFunction<double, WorldVector<double> > *fct,
	      const DOFVector<double> *lsFct_dof);

  /**
   * Print coordinates of all boundary elements to file. Name of file is 
   * read from init file.
   */
  static void printBoundaryElements(const std::string fn_str,
				    ElementLevelSet *elLS,
				    FiniteElemSpace *feSpace);
};

#endif  // AMDIS_COMPOSITEFEMMETHODS_H
